
Robinhood Functions
===================

----

.. note::

  Even though the functions are written as ``robin_stocks.module.function``, the module
  name is unimportant when calling a function. Simply use ``robin_stocks.function`` for all functions.

Sending Requests to API
-----------------------

----

.. automodule:: robin_stocks.robinhood.helper
   :members: request_get,request_post,request_delete,request_document

Logging In and Out
------------------

----

.. automodule:: robin_stocks.robinhood.authentication
   :members: login, logout, get_new_device_token

Loading Profiles
------------------

----

.. automodule:: robin_stocks.robinhood.profiles
   :members:

Getting Stock Information
-------------------------

----

.. automodule:: robin_stocks.robinhood.stocks
   :members:

Getting Option Information
--------------------------

----

.. automodule:: robin_stocks.robinhood.options
   :members:

Getting Market Information
--------------------------

----

.. automodule:: robin_stocks.robinhood.markets
   :members:

Getting Positions and Account Information
-----------------------------------------

----

.. automodule:: robin_stocks.robinhood.account
   :members:

Placing and Cancelling Orders
-----------------------------

----

.. automodule:: robin_stocks.robinhood.orders
   :members:

Getting Crypto Information
--------------------------

----

.. automodule:: robin_stocks.robinhood.crypto
   :members:

Export Information
--------------------------

----

.. automodule:: robin_stocks.robinhood.export
   :members:
